<div class="panel panel-{% if not comment.notified %}danger{% elif comment.is_from_client %}primary{% elif comment.internal %}default{% else %}info{% endif %}">
    <div class="panel-heading">
        <h3 class="panel-title {% if comment.is_from_client %}text-right{% endif %}">
            {{ comment.created|date:"d.m.Y H:i" }}, {{ comment.author|default:"Client" }}</h3>
    </div>
    <div class="panel-body">
        {% if comment.is_from_client %}
            <iframe src="{% url 'helpdesk_comment_email' comment.pk %}"
                    frameborder="none" width="100%" height="300px" sandbox></iframe>
        {% else %}
            {{ comment.body|safe }}
        {% endif %}

        <ol>
            {% for attachment in comment.attachments.all %}
                <li><a href="{{ attachment.attachment.url }}">{{ attachment.filename }}</a>
                    ({{ attachment.attachment.size|filesizeformat }})
                </li>
            {% endfor %}
        </ol>
    </div>
</div>