{% load i18n %}
{% language 'ru' %}
<p>Hi {{ ticket.assignee.username }},</p>

<p>An issue was created: <a href="{{ ticket.get_full_url }}">{{ ticket.title }}</a>.
    You're assigned to this issue.</p>
{% endlanguage %}